@@ -105,22 +105,23 @@ def holes_snapshot(c2_fp, diff_fp):
     return paths
 
 
-def __download_data__(xnat_instance, experiment_id, resource_name):
+def __download_data__(xnat_instance, experiment_id, resource_name, fn=None):
     import tempfile
     from nisnap import xnat
 
-    dl_functions = {'FREESURFER6': xnat.__download_freesurfer6__,
-                    'FREESURFER7': xnat.__download_freesurfer6__,
+    dl_functions = {'FREESURFER': xnat.__download_freesurfer__,
                     'SPM12': xnat.__download_spm12__,
                     'ASHS': xnat.__download_ashs__}
-
+    kwargs = {'raw': True, 'cache': False}
+    if fn:
+        kwargs['fn'] = fn
     # Find the right download function from nisnap and download resources
     try:
         for short_name, __dl__ in dl_functions.items():
             if short_name in resource_name:
                 filepaths = __dl__(xnat_instance, experiment_id,
                                    tempfile.gettempdir(), resource_name,
-                                   raw=True, cache=False)
+                                   **kwargs)
                 break
         bg = filepaths.pop(0)
         if len(filepaths) == 1:
@@ -171,10 +172,36 @@ class Snapshot:
     step = None
     n_slices = None
     threshold = None
+    contours = True
+    margin = 5
 
     def __init__(self):
         pass
 
+    def run(self, experiment_id):
+        import os
+        from ..test import Results
+
+        if os.getenv('SKIP_SNAPSHOTS_TESTS') == 'True':
+            return Results(experiment_id == self.passing[0],
+                           data=['Skipping it. (SKIP_SNAPSHOTS_TESTS)'])
+        try:
+            snap_fp = self.snap(experiment_id)
+        except Exception:
+            return Results(False, data=['Snapshot creation failed.'])
+
+        return Results(True, data=[snap_fp])
+
+    def report(self):
+        report = []
+        if self.results.has_passed:
+            path = self.results.data[0]
+            report.append('![snapshot](%s)' % path)
+        else:
+            report = self.results.data
+
+        return report
+
     def snap(self, experiment_id):
         """
         Creates a snapshot of the given resource and returns the path to the
@@ -188,9 +215,14 @@ class Snapshot:
         from nisnap import snap
         import tempfile
         import os
-        bg, filepaths = __download_data__(self.xnat_instance,
-                                          experiment_id,
-                                          self.resource_name)
+        kwargs = {'xnat_instance': self.xnat_instance,
+                  'experiment_id': experiment_id,
+                  'resource_name': self.resource_name}
+        if hasattr(self, 'fn'):
+            kwargs['fn'] = self.fn
+
+        bg, filepaths = __download_data__(**kwargs)
+
         sl = __select_slices__(filepaths, self.axes, self.rowsize,
                                self.figsize, step=self.step,
                                threshold=self.threshold)
@@ -201,12 +233,12 @@ class Snapshot:
             slices[a] = sx
 
         # Create snapshot with proper options
-        fd, snap_fp = tempfile.mkstemp(suffix=snap.format)
+        fd, snap_fp = tempfile.mkstemp(suffix=snap.__format__)
         os.close(fd)
 
         snap.plot_segment(filepaths, axes=self.axes, bg=bg, opacity=70,
                           slices=slices, animated=False, savefig=snap_fp,
                           figsize=self.figsize, rowsize=self.rowsize,
-                          contours=True, samebox=True,
-                          labels=self.labels)
+                          contours=self.contours, samebox=True,
+                          labels=self.labels, margin=self.margin)
         return snap_fp
