@@ -592,7 +592,7 @@ class HasCorrectSequences(ExperimentTest):
 
         def resolve_mutexes(seq_list, obligatory_items, mutexes, logs=[]):
 
-            for s in seq_list:
+            for s in set(seq_list):
                 for mutex_item1, mutex_item2 in mutexes.items():
                     if s == mutex_item1:
                         obligatory_items.pop(mutex_item2)
@@ -919,21 +919,6 @@ class HasCorrectSequenceAttributes(ExperimentTest):
         return report
 
 
-class IsFreeSurferRunnable(ExperimentTest):
-    """This test validates that the given MRSession fulfills the requirements
-    for running FreeSurfer. Fails if no MRSession scans are suited for running
-    FreeSurfer (see result/report data); passes otherwise."""
-
-    passing = 'BBRCDEV_E00375',
-    failing = 'BBRCDEV_E00483',
-
-    def run(self, experiment_id):
-        res = HasUsableT1(self.lut, self.xnat_instance).run(experiment_id)
-        if not res.has_passed:
-            return Results(False, data=['%s Not runnable.' % res.data[0]])
-        return Results(True, data=[])
-
-
 class HasUsableT1(ExperimentTest):
     """This test determines if session has a usable T1-weighted (`T1`) scan
     suited for further processing. This test passes either if there is
@@ -1126,6 +1111,26 @@ class HasPreferredT1(ExperimentTest):
         return report
 
 
+class IsFreeSurferRunnable(ExperimentTest):
+    """This test validates that the given MRSession fulfills the requirements
+    for running FreeSurfer. Fails if no MRSession scans are suited for running
+    FreeSurfer (see result/report data); passes otherwise."""
+
+    passing = 'BBRCDEV_E00375',
+    failing = 'BBRCDEV_E00483',
+    tests = [HasUsableT1]
+
+    def run(self, experiment_id):
+
+        for test in self.tests:
+            res = test(self.lut, self.xnat_instance).run(experiment_id)
+            if not res.has_passed:
+                return Results(False, data=['%s failed: %s Not runnable.'
+                                            % (test.__name__, res.data[0])])
+
+        return Results(True, data=[])
+
+
 class IsPhilipsVersion519(ExperimentTest):
     """The scanner software version used for generating an MRI dataset is
     registered in the DICOM metaheader as `SoftwareVersion(s)`. This test passes
@@ -1216,7 +1221,9 @@ class IsAccessionNumberUnique(ExperimentTest):
         excluded_projects = ['UCLM', 'HUGM', 'UPF_IR', 'PHILIPS', 'TEST_MRI',
                              'VOLUNTARIOS', 'jh_sandbox', 'GE-AIBL', 'BLSA']
         all_projects = self.get_all_projects(self.xnat_instance).keys()
-        projects = [e for e in all_projects if e not in excluded_projects]
+        projects = [e for e in all_projects
+                    if e not in excluded_projects
+                    and not e.startswith('_')]
 
         cols = ['ID', 'label', 'project', 'subject_ID']
         labels = self.xnat_instance.array.experiments(experiment_id=experiment_id,
@@ -1346,27 +1353,6 @@ class HasValidAccessionNumber(ExperimentTest):
         return Results(True, data=[])
 
 
-class IsDtifitRunnable(ExperimentTest):
-    """This test validates that the given MRSession fulfills the requirements
-    for running FSL dtifit application. Fails if no MRSession scans are suited
-    for running dtifit (see result/report data), passes otherwise."""
-
-    passing = 'BBRCDEV_E00272',
-    failing = 'BBRCDEV_E00007',
-
-    def run(self, experiment_id):
-        res_dwi = HasUsableDWI(self.lut, self.xnat_instance).run(experiment_id)
-        if not res_dwi.has_passed:
-            return Results(False, data=['%s Not runnable.' % res_dwi.data[0]])
-
-        res_rdwi = HasUsableReversedDWI(self.lut,
-                                        self.xnat_instance).run(experiment_id)
-        if not res_rdwi.has_passed:
-            return Results(False, data=['%s Not runnable.' % res_rdwi.data[0]])
-
-        return Results(True, data=[])
-
-
 class HasUsableDWI(ExperimentTest):
     """This test determines if session has a usable Diffusion-weighted (`DWI`)
     scan suited for further processing. This test passes either if there is
@@ -1375,88 +1361,39 @@ class HasUsableDWI(ExperimentTest):
 
     passing = 'BBRCDEV_E00272',
     failing = 'BBRCDEV_E00007',
+    scan_type = 'DWI'
+    required_tests = [HasBvecBval, HasNifti, IsClassicDICOM,
+                      HasPhilipsPrivateTags, HasUncompressedPixelData]
 
     def run(self, experiment_id):
-        dwi_scan_labels = self.lut.get('DWI', [])
+        scan_labels = self.lut.get(self.scan_type, [])
 
         columns = ['xsiType',
                    'xnat:mrScanData/type',
                    'xnat:mrScanData/quality',
                    'xnat:mrScanData/frames']
 
-        scans = self.xnat_instance.array.mrscans(experiment_id=experiment_id,
-                                                 columns=columns).data
-        scans = {s['xnat:mrscandata/id']: s for s in scans}
-
-        # filter out unsuitable scan_data items
-        valid_scans = {
-            str(scan_id): scan_data for scan_id, scan_data in scans.items()
-            if __is_valid_scan__(self.xnat_instance, scan_data)
-            and scan_data['xnat:mrscandata/type'].strip() in dwi_scan_labels}
-
-        if not valid_scans:
-            return Results(False, data=['No valid DWI scans found.'])
-        elif len(valid_scans) > 1:
-            return Results(False, data=['Multiple DWI scans.'])
-
-        scan_id = list(valid_scans.keys())[0]
-
-        # built-in checks
-        required = [HasBvecBval, HasNifti, IsClassicDICOM,
-                    HasPhilipsPrivateTags, HasUncompressedPixelData]
-        for each in required:
-            c = each(self.lut, self.xnat_instance).run(experiment_id, scan_id)
-            if not c.has_passed:
-                msg = 'Test %s failed.' % each.__name__
-                return Results(False, data=[msg])
-
-        return Results(True, data=[scan_id])
-
-    def report(self):
-        if self.results.has_passed:
-            report = ['Usable DWI: %s' % list(self.results.data)[0]]
-        else:
-            report = [list(self.results.data)[0]]
-        return report
-
-
-class HasUsableT2(ExperimentTest):
-    """Test determines if session has a usable T2-weighted (`T2`) scan
-    suited for further processing. This test passes either if there is
-    one unique and valid T2 sequence or if, in case of multiple matches,
-    only one of them is labelled as `usable`. Fails otherwise."""
-
-    passing = 'BBRCDEV_E00272',
-    failing = 'BBRCDEV_E00007',
-
-    def run(self, experiment_id):
-        t2w_scan_labels = self.lut.get('T2', [])
-
-        cols = ['xnat:mrScanData/type',
-                'xnat:mrScanData/quality',
-                'xnat:mrScanData/frames']
-
         data = self.xnat_instance.array.mrscans(experiment_id=experiment_id,
-                                                columns=cols).data
+                                                columns=columns).data
         scans = {s['xnat:mrscandata/id']: s for s in data}
 
         # filter out unsuitable scan_data items
         valid_scans = {
             str(scan_id): scan_data for scan_id, scan_data in scans.items()
             if __is_valid_scan__(self.xnat_instance, scan_data)
-            and scan_data['xnat:mrscandata/type'].strip() in t2w_scan_labels}
+            and scan_data['xnat:mrscandata/type'].strip() in scan_labels}
 
         if not valid_scans:
-            return Results(False, data=['No valid T2 scans found.'])
+            return Results(False,
+                           data=['No valid %s scans found' % self.scan_type])
         elif len(valid_scans) > 1:
-            return Results(False, data=['Multiple T2 scans.'])
+            return Results(False,
+                           data=['Multiple %s scans.' % self.scan_type])
 
         scan_id = list(valid_scans.keys())[0]
 
         # built-in checks
-        required = [HasNifti, IsClassicDICOM, HasUncompressedPixelData]
-
-        for each in required:
+        for each in self.required_tests:
             c = each(self.lut, self.xnat_instance).run(experiment_id, scan_id)
             if not c.has_passed:
                 msg = 'Test %s failed.' % each.__name__
@@ -1466,13 +1403,44 @@ class HasUsableT2(ExperimentTest):
 
     def report(self):
         if self.results.has_passed:
-            report = ['Usable T2: %s' % list(self.results.data)[0]]
+            report = ['Usable %s: %s' % (self.scan_type,
+                                         list(self.results.data)[0])]
         else:
             report = [list(self.results.data)[0]]
         return report
 
 
-class IsT2T1CoregistrationRunnable(ExperimentTest):
+class HasUsableReversedDWI(HasUsableDWI):
+    passing = 'BBRCDEV_E00272',
+    failing = 'BBRCDEV_E00007',
+    scan_type = 'rDWI'
+    required_tests = [HasNifti, IsClassicDICOM, HasUncompressedPixelData]
+    __doc__ = HasUsableDWI.__doc__.replace('Diffusion',
+                                           'reversed phase-encoding Diffusion')
+    __doc__ = __doc__.replace('DWI', 'rDWI')
+
+
+class IsDtifitRunnable(IsFreeSurferRunnable):
+    """This test validates that the given MRSession fulfills the requirements
+    for running FSL dtifit application. Fails if no MRSession scans are suited
+    for running dtifit (see result/report data), passes otherwise."""
+
+    passing = 'BBRCDEV_E00272',
+    failing = 'BBRCDEV_E00007',
+    tests = [HasUsableDWI, HasUsableReversedDWI]
+
+
+class HasUsableT2(HasUsableDWI):
+    passing = 'BBRCDEV_E00272',
+    failing = 'BBRCDEV_E00007',
+    scan_type = 'T2'
+    required_tests = [HasNifti, IsClassicDICOM, HasUncompressedPixelData]
+    __doc__ = HasUsableDWI.__doc__.replace('Diffusion',
+                                           'T2')
+    __doc__ = __doc__.replace('DWI', 'T2')
+
+
+class IsT2T1CoregistrationRunnable(IsFreeSurferRunnable):
     """This test validates that the given MRSession fulfills the requirements
     to run a multimodal pipeline for the coregistration of T2 scan image into T1
     image space. Fails if no MRSession scans are suited for running
@@ -1480,72 +1448,20 @@ class IsT2T1CoregistrationRunnable(ExperimentTest):
 
     passing = 'BBRCDEV_E01613',
     failing = 'BBRCDEV_E00385',
-
-    def run(self, experiment_id):
-
-        res_t1 = HasUsableT1(self.lut, self.xnat_instance).run(experiment_id)
-        if not res_t1.has_passed:
-            return Results(False, data=['%s Not runnable.' % res_t1.data[0]])
-
-        res_t2 = HasUsableT2(self.lut, self.xnat_instance).run(experiment_id)
-        if not res_t2.has_passed:
-            return Results(False, data=['%s Not runnable.' % res_t2.data[0]])
-
-        return Results(True, data=[])
+    tests = [HasUsableT1, HasUsableT2]
 
 
-class HasUsableIR(ExperimentTest):
-    """Test determines if session has a usable Inversion Recovery (`IR`) scan
-    suited for further processing. This test passes either if there is
-    one unique and valid IR sequence or if, in case of multiple matches,
-    only one of them is labelled as `usable`. Fails otherwise."""
-
+class HasUsableIR(HasUsableDWI):
     passing = 'BBRCDEV_E02443',
     failing = 'BBRCDEV_E00281',
-
-    def run(self, experiment_id):
-        ir_scan_labels = self.lut.get('IR', [])
-
-        cols = ['xnat:mrScanData/type',
-                'xnat:mrScanData/quality',
-                'xnat:mrScanData/frames']
-        data = self.xnat_instance.array.mrscans(experiment_id=experiment_id,
-                                                columns=cols).data
-        scans = {s['xnat:mrscandata/id']: s for s in data}
-
-        # filter out unsuitable scan_data items
-        valid_scans = {
-            str(scan_id): scan_data for scan_id, scan_data in scans.items()
-            if __is_valid_scan__(self.xnat_instance, scan_data)
-            and scan_data['xnat:mrscandata/type'].strip() in ir_scan_labels}
-
-        if not valid_scans:
-            return Results(False, data=['No valid IR scans found.'])
-        elif len(valid_scans) > 1:
-            return Results(False, data=['Multiple IR scans.'])
-
-        scan_id = list(valid_scans.keys())[0]
-
-        # built-in checks
-        required = [HasNifti, IsClassicDICOM, HasUncompressedPixelData]
-
-        for each in required:
-            c = each(self.lut, self.xnat_instance).run(experiment_id, scan_id)
-            if not c.has_passed:
-                msg = 'Test %s failed.' % each.__name__
-                return Results(False, data=[msg])
-
-        return Results(True, data=[scan_id])
-
-    def report(self):
-        if self.results.has_passed:
-            report = ['Usable IR: %s' % list(self.results.data)[0]]
-        else:
-            report = [list(self.results.data)[0]]
-        return report
+    scan_type = 'IR'
+    required_tests = [HasNifti, IsClassicDICOM, HasUncompressedPixelData]
+    __doc__ = HasUsableDWI.__doc__.replace('Diffusion-weighted',
+                                           'Inversion Recovery')
+    __doc__ = __doc__.replace('DWI', 'IR')
 
 
-class IsASHSRunnable(ExperimentTest):
+class IsASHSRunnable(IsFreeSurferRunnable):
     """This test validates that the given MRSession fulfills the requirements
     to run `ASHS`, a multimodal pipeline for the segmentation of hippocampal
     subfields that uses a T1w and a Inversion Recovery (IR) set of scan images.
@@ -1554,71 +1470,7 @@ class IsASHSRunnable(ExperimentTest):
 
     passing = 'BBRCDEV_E02443',
     failing = 'BBRCDEV_E00007',
-
-    def run(self, experiment_id):
-
-        res_t1 = HasUsableT1(self.lut, self.xnat_instance).run(experiment_id)
-        if not res_t1.has_passed:
-            return Results(False, data=['%s Not runnable.' % res_t1.data[0]])
-
-        res_ir = HasUsableIR(self.lut, self.xnat_instance).run(experiment_id)
-        if not res_ir.has_passed:
-            return Results(False, data=['%s Not runnable.' % res_ir.data[0]])
-
-        return Results(True, data=[])
-
-
-class HasUsableReversedDWI(ExperimentTest):
-    """This test determines if session has a usable reversed phase-encoding
-    Diffusion-weighted (`rDWI`) scan suited for further processing. This test
-    passes either if there is one unique and valid rDWI sequence or if, in
-    case of multiple matches, only one of them is labelled as `usable`.
-    Fails otherwise."""
-
-    passing = 'BBRCDEV_E00272',
-    failing = 'BBRCDEV_E00007',
-
-    def run(self, experiment_id):
-        dwi_scan_labels = self.lut.get('rDWI', [])
-
-        cols = ['xsiType',
-                'xnat:mrScanData/type',
-                'xnat:mrScanData/quality',
-                'xnat:mrScanData/frames']
-        scans = self.xnat_instance.array.mrscans(experiment_id=experiment_id,
-                                                 columns=cols).data
-        scans = {s['xnat:mrscandata/id']: s for s in scans}
-
-        # filter out unsuitable scan_data items
-        valid_scans = {
-            str(scan_id): scan_data for scan_id, scan_data in scans.items()
-            if __is_valid_scan__(self.xnat_instance, scan_data)
-            and scan_data['xnat:mrscandata/type'].strip() in dwi_scan_labels}
-
-        if not valid_scans:
-            return Results(False, data=['No valid rDWI scans found.'])
-        elif len(valid_scans) > 1:
-            return Results(False, data=['Multiple rDWI scans.'])
-
-        scan_id = list(valid_scans.keys())[0]
-
-        # built-in checks
-        required = [HasNifti, IsClassicDICOM, HasUncompressedPixelData]
-
-        for each in required:
-            c = each(self.lut, self.xnat_instance).run(experiment_id, scan_id)
-            if not c.has_passed:
-                msg = 'Test %s failed.' % each.__name__
-                return Results(False, data=[msg])
-
-        return Results(True, data=[scan_id])
-
-    def report(self):
-        if self.results.has_passed:
-            report = ['Usable rDWI: %s' % list(self.results.data)[0]]
-        else:
-            report = [list(self.results.data)[0]]
-        return report
+    tests = [HasUsableT1, HasUsableIR]
 
 
 class HasValidDcm2niixVersion(ExperimentTest):
@@ -1815,59 +1667,17 @@ class IsInsertDateConsistent(ExperimentTest):
         return report
 
 
-class HasUsableFLAIR(ExperimentTest):
-    """This test checks if a session has a usable FLAIR scan suited for further
-    processing. Passes either if there is one unique and valid FLAIR sequence
-    or if, in case of multiple matches, only one of them is labeled as `usable`.
-    Fails otherwise."""
-
+class HasUsableFLAIR(HasUsableDWI):
     passing = 'BBRCDEV_E02939',
     failing = 'BBRCDEV_E02872',
-
-    def run(self, experiment_id):
-        flair_scan_labels = self.lut.get('FLAIR', [])
-
-        columns = ['xnat:mrScanData/type',
-                   'xnat:mrScanData/quality',
-                   'xnat:mrScanData/frames']
-
-        data = self.xnat_instance.array.mrscans(experiment_id=experiment_id,
-                                                columns=columns).data
-        scans = {s['xnat:mrscandata/id']: s for s in data}
-
-        # filter out unsuitable scan_data items
-        valid_scans = {
-            str(scan_id): scan_data for scan_id, scan_data in scans.items()
-            if __is_valid_scan__(self.xnat_instance, scan_data)
-            and scan_data['xnat:mrscandata/type'].strip() in flair_scan_labels}
-
-        if not valid_scans:
-            return Results(False, data=['No valid FLAIR scans found.'])
-        elif len(valid_scans) > 1:
-            return Results(False, data=['Multiple FLAIR scans.'])
-
-        scan_id = list(valid_scans.keys())[0]
-
-        # built-in checks
-        required = [HasNifti, IsClassicDICOM, HasUncompressedPixelData]
-
-        for each in required:
-            c = each(self.lut, self.xnat_instance).run(experiment_id, scan_id)
-            if not c.has_passed:
-                msg = 'Test %s failed.' % each.__name__
-                return Results(False, data=[msg])
-
-        return Results(True, data=[scan_id])
-
-    def report(self):
-        if self.results.has_passed:
-            report = ['Usable FLAIR: %s' % list(self.results.data)[0]]
-        else:
-            report = [list(self.results.data)[0]]
-        return report
+    scan_type = 'FLAIR'
+    required_tests = [HasNifti, IsClassicDICOM, HasUncompressedPixelData]
+    __doc__ = HasUsableDWI.__doc__.replace('Diffusion-weighted',
+                                           'Fluid-Attenuated Inversion Recovery')
+    __doc__ = __doc__.replace('DWI', 'FLAIR')
 
 
-class IsBAMOSRunnable(ExperimentTest):
+class IsBAMOSRunnable(IsFreeSurferRunnable):
     """This test checks that a given MRSession fulfills the requirements to run
     `BAMOS` (Sudre et al., IEEE TMI, 2015), a multimodal pipeline for the
     segmentation of white matter lesions. `BAMOS` works with T1s and FLAIRs.
@@ -1875,13 +1685,37 @@ class IsBAMOSRunnable(ExperimentTest):
 
     passing = 'BBRCDEV_E02939',
     failing = 'BBRCDEV_E02872',
+    tests = [HasUsableT1, HasUsableFLAIR]
 
-    def run(self, experiment_id):
 
-        for test in [HasUsableT1, HasUsableFLAIR]:
-            res = test(self.lut, self.xnat_instance).run(experiment_id)
-            if not res.has_passed:
-                return Results(False, data=['%s failed: %s Not runnable.'
-                                            % (test.__name__, res.data[0])])
+class HasUsableASL(HasUsableDWI):
+    passing = 'BBRCDEV_E00276',
+    failing = 'BBRCDEV_E00013',
+    scan_type = 'ASL'
+    required_tests = [HasNifti, IsClassicDICOM, HasUncompressedPixelData]
+    __doc__ = HasUsableDWI.__doc__.replace('Diffusion-weighted',
+                                           '(pseudo-continuous) '
+                                           'Arterial Spin Labeling')
+    __doc__ = __doc__.replace('DWI', 'ASL')
 
-        return Results(True, data=[])
+
+class HasUsableM0(HasUsableDWI):
+    passing = 'BBRCDEV_E00276',
+    failing = 'BBRCDEV_E00013',
+    scan_type = 'M0'
+    required_tests = [HasNifti, IsClassicDICOM, HasUncompressedPixelData]
+    __doc__ = HasUsableDWI.__doc__.replace('Diffusion-weighted',
+                                           'Equilibrium Magnetization')
+    __doc__ = __doc__.replace('DWI', 'M0')
+
+
+class IsBASILRunnable(IsFreeSurferRunnable):
+    """This test checks that a given MRSession fulfills the requirements to run
+    `BASIL` (_Bayesian Inference for Arterial Spin Labeling MRI_), a multimodal
+    pipeline for the quantification of cerebral perfusion on ASL data. `BASIL`
+    requires a T1 image, an ASL image and a M0 calibration image to run. This
+    test passes if the right scan images can be found, fails otherwise."""
+
+    passing = 'BBRCDEV_E00276',
+    failing = 'BBRCDEV_E00013',
+    tests = [HasUsableT1, HasUsableASL, HasUsableM0]
