@@ -148,7 +148,10 @@ class ArchivingValidator(Validator):
                  data.HasUsableIR,
                  data.IsASHSRunnable,
                  data.HasUsableFLAIR,
-                 data.IsBAMOSRunnable]
+                 data.IsBAMOSRunnable,
+                 data.HasUsableASL,
+                 data.HasUsableM0,
+                 data.IsBASILRunnable]
         super(type(self), self).__init__(tests, lut, xnat_instance)
 
 
@@ -388,3 +391,40 @@ class FreeSurfer7Validator(Validator):
                  freesurfer7.ReconAllAparcSnapshot]
                  # freesurfer7.HasAbnormalAsegFeatures]
         super(type(self), self).__init__(tests, lut, xnat_instance)
+
+
+class BASILValidator(Validator):
+    def __init__(self, lut, xnat_instance):
+        from bbrc.validation.processing import basil
+        tests = [basil.HasCorrectNumberOfItems,
+                 basil.HasCorrectItems,
+                 basil.HasCorrectFSLVersion,
+                 basil.HasCorrectOxfordASLVersion,
+                 basil.IsT1Session1,
+                 basil.IsT1Session3,
+                 basil.IsGMPerfusionMeanConsistent,
+                 basil.IsWMPerfusionMeanConsistent,
+                 basil.PerfusionSnapshot,
+                 basil.HasNormalFSLANATVolumes,
+                 basil.FSLANATSegmentationSnapshot]
+        super(type(self), self).__init__(tests, lut, xnat_instance)
+
+
+class FreeSurfer7ExtrasValidator(Validator):
+    def __init__(self, lut, xnat_instance):
+        from bbrc.validation.processing import freesurfer7_extras as fs7_extras
+        tests = [fs7_extras.HasCorrectItems,
+                 fs7_extras.HasCorrectFreeSurferVersion,
+                 fs7_extras.HasCorrectOSVersion,
+                 fs7_extras.HasExpectedHypothalamicSegmentationResolution,
+                 fs7_extras.HasAllBrainstemRegions,
+                 fs7_extras.HasNormalBrainstemVolumes,
+                 fs7_extras.AreBrainstemVolumesConsistent,
+                 fs7_extras.HasAllHypothalamicRegions,
+                 fs7_extras.HasNormalHypothalamicVolumes,
+                 fs7_extras.HasAllThalamicNucleiRegions,
+                 fs7_extras.HasNormalThalamicNucleiVolumes,
+                 fs7_extras.BrainstemSnapshot,
+                 fs7_extras.HypothalamusSnapshot,
+                 fs7_extras.ThalamusNucleiSnapshot]
+        super(type(self), self).__init__(tests, lut, xnat_instance)
